@@ -1,6 +1,6 @@
-# $Id: Standard.pm 844 2009-03-05 00:07:26Z rvos $
+# $Id: Standard.pm 1235 2010-03-02 16:11:07Z rvos $
 package Bio::Phylo::Matrices::Datatype::Standard;
-use Bio::Phylo::Matrices::Datatype;
+use Bio::Phylo::Matrices::Datatype ();
 use strict;
 use vars qw($LOOKUP @ISA $MISSING $GAP);
 @ISA = qw(Bio::Phylo::Matrices::Datatype);
@@ -36,7 +36,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: Standard.pm 844 2009-03-05 00:07:26Z rvos $
+ $Id: Standard.pm 1235 2010-03-02 16:11:07Z rvos $
 
 =cut
 
